#ifndef GCC_TM_H
#define GCC_TM_H
#define TARGET_CPU_DEFAULT (TARGET_CPU_generic | ((  AARCH64_FL_FOR_ARCH8) << TARGET_CPU_NBITS))
#ifndef LIBC_GLIBC
# define LIBC_GLIBC 1
#endif
#ifndef LIBC_UCLIBC
# define LIBC_UCLIBC 2
#endif
#ifndef LIBC_BIONIC
# define LIBC_BIONIC 3
#endif
#ifndef LIBC_MUSL
# define LIBC_MUSL 4
#endif
#ifndef TARGET_ENABLE_BTI
# define TARGET_ENABLE_BTI 1
#endif
#ifndef TARGET_ENABLE_PAC_RET
# define TARGET_ENABLE_PAC_RET 1
#endif
#ifdef IN_GCC
# include "options.h"
# include "insn-constants.h"
# include "config/aarch64/biarchlp64.h"
# include "config/aarch64/aarch64.h"
# include "config/dbxelf.h"
# include "config/elfos.h"
# include "config/newlib-stdint.h"
# include "config/aarch64/aarch64-elf.h"
# include "config/aarch64/aarch64-errata.h"
# include "config/aarch64/aarch64-elf-raw.h"
# include "config/initfini-array.h"
#endif
#if defined IN_GCC && !defined GENERATOR_FILE && !defined USED_FOR_TARGET
# include "insn-flags.h"
#endif
#if defined IN_GCC && !defined GENERATOR_FILE
# include "insn-modes.h"
#endif
# include "./defaults.h"
#endif /* GCC_TM_H */
